@@ -17,7 +17,7 @@ use File::Spec;
 
 no warnings 'utf8';
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 our $PACKAGE = __PACKAGE__;
 
 ### begin XS only ###
@@ -89,9 +89,9 @@ my $DefaultRearrange = [ 0x0E40..0x0E44, 0x0EC0..0x0EC4 ];
 my $HighestVCE = pack(VCE_TEMPLATE, 0, 0xFFFE, 0x20, 0x5, 0xFFFF);
 my $minimalVCE = pack(VCE_TEMPLATE, 0,      1, 0x20, 0x5, 0xFFFE);
 
-sub UCA_Version { "32" }
+sub UCA_Version { "34" }
 
-sub Base_Unicode_Version { "8.0.0" }
+sub Base_Unicode_Version { "9.0.0" }
 
 ######
 
@@ -190,6 +190,7 @@ my %DerivCode = (
    28 => \&_derivCE_24, # 28 == 24
    30 => \&_derivCE_24, # 30 == 24
    32 => \&_derivCE_32,
+   34 => \&_derivCE_34,
 );
 
 sub checkCollator {
@@ -1098,7 +1099,7 @@ If the revision (previously "tracking version") number of UCA is given,
 behavior of that revision is emulated on collating.
 If omitted, the return value of C<UCA_Version()> is used.
 
-The following revisions are supported.  The default is 32.
+The following revisions are supported.  The default is 34.
 
      UCA       Unicode Standard         DUCET (@version)
    -------------------------------------------------------
@@ -1115,6 +1116,7 @@ The following revisions are supported.  The default is 32.
      28             6.3.0               6.3.0 (6.3.0)
      30             7.0.0               7.0.0 (7.0.0)
      32             8.0.0               8.0.0 (8.0.0)
+     34             9.0.0               9.0.0 (9.0.0)
 
 * See below for C<long_contraction> with C<UCA_Version> 22 and 24.
 
@@ -1454,13 +1456,13 @@ those in the CJK Unified Ideographs Extension A etc.
     U+4E00..U+9FC3 if UCA_Version is 18.
     U+4E00..U+9FCB if UCA_Version is 20 or 22.
     U+4E00..U+9FCC if UCA_Version is 24 to 30.
-    U+4E00..U+9FD5 if UCA_Version is 32.
+    U+4E00..U+9FD5 if UCA_Version is 32 or 34.
 
     In the CJK Unified Ideographs Extension blocks:
     Ext.A (U+3400..U+4DB5) and Ext.B (U+20000..U+2A6D6) in any UCA_Version.
     Ext.C (U+2A700..U+2B734) if UCA_Version is 20 or later.
     Ext.D (U+2B740..U+2B81D) if UCA_Version is 22 or later.
-    Ext.E (U+2B820..U+2CEA1) if UCA_Version is 32.
+    Ext.E (U+2B820..U+2CEA1) if UCA_Version is 32 or later.
 
 Through C<overrideCJK>, ordering of CJK unified ideographs (including
 extensions) can be overridden.
@@ -2037,7 +2039,8 @@ The most preferable one is "The Default Unicode Collation Element Table"
 
    http://www.unicode.org/Public/UCA/
 
-   http://www.unicode.org/Public/UCA/latest/allkeys.txt (latest version)
+   http://www.unicode.org/Public/UCA/latest/allkeys.txt
+   (latest version)
 
 If DUCET is not installed, it is recommended to copy the file
 from http://www.unicode.org/Public/UCA/latest/allkeys.txt
@@ -2088,8 +2091,8 @@ This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 The file Unicode/Collate/allkeys.txt was copied verbatim
-from L<http://www.unicode.org/Public/UCA/8.0.0/allkeys.txt>.
-For this file, Copyright (c) 2001-2015 Unicode, Inc.; distributed
+from L<http://www.unicode.org/Public/UCA/9.0.0/allkeys.txt>.
+For this file, Copyright (c) 2016 Unicode, Inc.; distributed
 under the Terms of Use in L<http://www.unicode.org/terms_of_use.html>
 
 =head1 SEE ALSO
